==> odoo_18.0.20250316.zip: odoo-18.0.post20250316/odoo/addons/account/tests/__init__.py <==
from . import test_account_move_reconcile
from . import test_account_move_payments_widget
from . import test_account_move_out_invoice
from . import test_account_move_out_refund
from . import test_account_move_in_invoice
from . import test_account_move_in_refund
from . import test_account_move_entry
from . import test_account_move_date_algorithm
from . import test_account_inalterable_hash
from . import test_account_journal
from . import test_account_account
from . import test_account_tax
from . import test_account_analytic
from . import test_account_payment
from . import test_account_payment_method_line
from . import test_account_move_duplicate
from . import test_account_payment_duplicate
from . import test_account_bank_statement
from . import test_account_invoice_report
from . import test_account_move_line_tax_details
from . import test_account_journal_dashboard_common
from . import test_account_journal_dashboard
from . import test_account_lock_exception
from . import test_audit_trail
from . import test_chart_template
from . import test_company_branch
from . import test_digest
from . import test_download_docs
from . import test_fiscal_position
from . import test_sequence_mixin
from . import test_tax
from . import test_taxes_computation
from . import test_taxes_tax_totals_summary
from . import test_invoice_taxes
from . import test_account_move_send
from . import test_account_all_l10n
from . import test_portal_attachment
from . import test_portal_invoice
from . import test_tax_report
from . import test_transfer_wizard
from . import test_account_incoming_supplier_invoice
from . import test_payment_term
from . import test_account_payment_items
from . import test_account_payment_register
from . import test_tour
from . import test_early_payment_discount
from . import test_ir_actions_report
from . import test_multivat
from . import test_account_partner
from . import test_setup_wizard
from . import test_structured_reference
from . import test_product
from . import test_unexpected_invoice
from . import test_mail_tracking_value
from . import test_res_partner_merge
from . import test_account_merge_wizard
from . import test_account_move_attachment

==> odoo_18.0.20250905.zip: odoo-18.0.post20250905/odoo/addons/account/tests/__init__.py <==
from . import test_account_move_reconcile
from . import test_account_move_payments_widget
from . import test_account_move_out_invoice
from . import test_account_move_out_refund
from . import test_account_move_in_invoice
from . import test_account_move_in_refund
from . import test_account_move_entry
from . import test_account_move_date_algorithm
from . import test_account_inalterable_hash
from . import test_account_journal
from . import test_account_account
from . import test_account_tax
from . import test_account_analytic
from . import test_account_payment
from . import test_account_payment_method_line
from . import test_account_move_duplicate
from . import test_account_payment_duplicate
from . import test_account_bank_statement
from . import test_account_invoice_report
from . import test_account_move_line_tax_details
from . import test_account_journal_dashboard_common
from . import test_account_journal_dashboard
from . import test_account_lock_exception
from . import test_audit_trail
from . import test_chart_template
from . import test_company_branch
from . import test_digest
from . import test_download_docs
from . import test_fiscal_position
from . import test_sequence_mixin
from . import test_tax
from . import test_taxes_base_lines_tax_details
from . import test_taxes_computation
from . import test_taxes_tax_totals_summary
from . import test_invoice_taxes
from . import test_account_move_send
from . import test_account_all_l10n
from . import test_portal_attachment
from . import test_portal_invoice
from . import test_tax_report
from . import test_transfer_wizard
from . import test_account_incoming_supplier_invoice
from . import test_payment_term
from . import test_account_payment_items
from . import test_account_payment_register
from . import test_account_report
from . import test_tour
from . import test_early_payment_discount
from . import test_ir_actions_report
from . import test_multivat
from . import test_account_partner
from . import test_setup_wizard
from . import test_structured_reference
from . import test_product
from . import test_unexpected_invoice
from . import test_mail_tracking_value
from . import test_res_partner_merge
from . import test_account_merge_wizard
from . import test_account_move_attachment
from . import test_account_move_auto_post
from . import test_dict_to_xml
from . import test_duplicate_res_partner_bank
